Learn R Programming

eurlex (version 0.3.5)

elx_label_eurovoc: Label EuroVoc concepts

Description

Create a look-up table with labels for EuroVoc concept URIs. Only unique identifiers are returned.

Usage

elx_label_eurovoc(uri_eurovoc = "", alt_labels = FALSE, language = "en")

Arguments

uri_eurovoc

Character vector with valid EuroVoc URIs

alt_labels

If `TRUE`, results include comma-separated alternative labels in addition to the preferred label

language

Language in which to return the labels, in ISO 639 2-char code

Value

A `tibble` containing EuroVoc unique concept identifiers and labels.

Examples

Run this code
# NOT RUN {
elx_label_eurovoc(uri_eurovoc = "http://eurovoc.europa.eu/5760", alt_labels = TRUE, language = "fr")
elx_label_eurovoc(uri_eurovoc = c("http://eurovoc.europa.eu/5760","http://eurovoc.europa.eu/576"))
# }

Run the code above in your browser using DataLab