Learn R Programming

eurlex (version 0.3.5)

elx_make_query: Create SPARQL queries

Description

Generates pre-defined or manual SPARQL queries to retrieve document ids from Cellar. List of available resource types: http://publications.europa.eu/resource/authority/resource-type . Note that not all resource types are compatible with default parameter values.

Usage

elx_make_query(
  resource_type = c("directive", "regulation", "decision", "recommendation", "intagr",
    "caselaw", "manual", "proposal", "national_impl", "any"),
  manual_type = "",
  directory = NULL,
  sector = NULL,
  include_corrigenda = FALSE,
  include_celex = TRUE,
  include_lbs = FALSE,
  include_date = FALSE,
  include_date_force = FALSE,
  include_date_endvalid = FALSE,
  include_date_transpos = FALSE,
  include_date_lodged = FALSE,
  include_force = FALSE,
  include_eurovoc = FALSE,
  include_author = FALSE,
  include_citations = FALSE,
  include_court_procedure = FALSE,
  include_directory = FALSE,
  include_sector = FALSE,
  order = FALSE,
  limit = NULL
)

Arguments

resource_type

Type of resource to be retrieved via SPARQL query

manual_type

Define manually the type of resource to be retrieved

directory

Restrict the results to a given directory code

sector

Restrict the results to a given sector code

include_corrigenda

If `TRUE`, results include corrigenda

include_celex

If `TRUE`, results include CELEX identifier for each resource URI

include_lbs

If `TRUE`, results include legal bases of legislation

include_date

If `TRUE`, results include document date

include_date_force

If `TRUE`, results include date of entry into force

include_date_endvalid

If `TRUE`, results include date of end of validity

include_date_transpos

If `TRUE`, results include date of transposition deadline for directives

include_date_lodged

If `TRUE`, results include date a court case was lodged with the court

include_force

If `TRUE`, results include whether legislation is in force

include_eurovoc

If `TRUE`, results include EuroVoc descriptors of subject matter

include_author

If `TRUE`, results include document author(s)

include_citations

If `TRUE`, results include citations (CELEX-labelled)

include_court_procedure

If `TRUE`, results include type of court procedure and outcome

include_directory

If `TRUE`, results include the Eur-Lex directory code

include_sector

If `TRUE`, results include the Eur-Lex sector code

order

Order results by ids

limit

Limit the number of results, for testing purposes mainly

Value

A character string containing the SPARQL query

Examples

Run this code
# NOT RUN {
elx_make_query(resource_type = "directive", include_date = TRUE, include_force = TRUE)
elx_make_query(resource_type = "regulation", include_corrigenda = TRUE, order = TRUE)
elx_make_query(resource_type = "caselaw")
elx_make_query(resource_type = "manual", manual_type = "SWD")
# }

Run the code above in your browser using DataLab